=== modified file 'ivle/database.py'
--- ivle/database.py	2009-04-06 10:21:22 +0000
+++ ivle/database.py	2009-04-06 13:42:10 +0000
@@ -612,7 +612,10 @@
             if user.admin:
                 perms.add('edit')
                 perms.add('view')
-            elif 'lecturer' in set((e.role for e in user.active_enrolments)):
+            elif u'lecturer' in set((e.role for e in user.active_enrolments)):
+                perms.add('edit')
+                perms.add('view')
+            elif u'tutor' in set((e.role for e in user.active_enrolments)):
                 perms.add('edit')
                 perms.add('view')
             

=== added file 'ivle/webapp/admin/project_service.py'
--- ivle/webapp/admin/project_service.py	1970-01-01 00:00:00 +0000
+++ ivle/webapp/admin/project_service.py	2009-04-06 13:37:38 +0000
@@ -0,0 +1,55 @@
+# IVLE - Informatics Virtual Learning Environment
+# Copyright (C) 2007-2009 The University of Melbourne
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+
+# Author: Nick Chadwick
+
+import ivle.database
+from ivle.data import ProjectSet, Project, Subject, Semester, Offering
+
+from ivle.webapp.base.rest import (XHTMLRESTView, named_operation,
+                                   require_permission)
+from ivle.webapp.errors import NotFound
+
+class ProjectSETRESTView(XHTMLRESTView):
+    """Rest view for a project.
+    
+    Add new, delete, edit functionality is given here."""
+    template = "projectset.html"
+    
+    def __init__(self, req, subject, year, semester, projectset):
+        self.context = req.store.find(Offering,
+            Offering.subject_id == Subject.id,
+            Subject.short_name == unicode(subject),
+            Offering.semester_id == Semester.id,
+            Semester.year == unicode(year),
+            Semester.semester == unicode(semester))
+        
+        if self.context is None:
+            raise NotFound()
+        
+        self.projectset = req.store.find(ProjectSet,
+            ProjectSet.offering_id == self.context.id,
+            ProjectSet.id == int(projectset))
+    
+    @require_permission('edit')
+    def PUT(self, req, max_students):
+        """Add a new ProjectSet"""
+        new_projectset = ProjectSet()
+        new_projectset.max_students = int(max_students)
+        new_projectset.offering = self.context
+        
+        

=== added file 'ivle/webapp/admin/subject-media/project.css'
=== modified file 'ivle/webapp/admin/subject.py'
--- ivle/webapp/admin/subject.py	2009-03-03 06:57:03 +0000
+++ ivle/webapp/admin/subject.py	2009-04-06 13:37:38 +0000
@@ -124,11 +124,38 @@
         ctx['offering'] = self.context
         ctx['errors'] = errors
 
+class SubjectProjectSetView(XHTMLView):
+    """View the ProjectSets for a subject."""
+    template = 'subject_projects.html'
+    permission = 'edit'
+    
+    def __init__(self, req, subject, year, semester):
+        self.context = req.store.find(Offering,
+            Offering.subject_id == Subject.id,
+            Subject.short_name == subject,
+            Offering.semester_id == Semester.id,
+            Semester.year == year,
+            Semester.semester == semester).one()
+
+        if not self.context:
+            raise NotFound()
+    
+    def populate(self, req, ctx):
+        self.plugin_styles[Plugin] = ["project.css"]
+        ctx['offering'] = self.context
+
+class ProjectSetView(XHTMLView):
+    """View the submissions for a ProjectSet"""
+    template = 'projectsubmissions.html'
+    permission = 'edit'
 
 class Plugin(ViewPlugin, MediaPlugin):
     urls = [
         ('subjects/', SubjectsView),
         ('subjects/:subject/:year/:semester/+enrolments/+new', EnrolView),
+        ('subjects/:subject/:year/:semester/+projects', SubjectProjectSetView),
+        #API Views
+        
     ]
 
     tabs = [

=== added file 'ivle/webapp/admin/subject_projects.html'
--- ivle/webapp/admin/subject_projects.html	1970-01-01 00:00:00 +0000
+++ ivle/webapp/admin/subject_projects.html	2009-04-06 13:37:38 +0000
@@ -0,0 +1,41 @@
+<html xmlns="http://www.w3.org/1999/xhtml"
+      xmlns:py="http://genshi.edgewall.org/">
+  <head>
+    <title>Projects - ${offering.subject.name}</title>
+  </head>
+  <body>
+    <py:def function="project_url(offering, project)">/subjects/${offering.subject.short_name}/${offering.semester.year}/${offering.semester.semester}/+project/${project.short_name}</py:def>
+    <h1>${offering.subject.name} - Projects</h1>
+    <div id="ivle_padding">
+      <ul id="projectset_list">
+        <py:for each="projectset in offering.project_sets">
+          <li id="projectset_${projectset.id}">
+            <h3>ProjectSet</h3>
+            <p>Max Size Per Group: ${projectset.max_students_per_group}</p>
+            <ul id="projects_${projectset.id}">
+              <py:for each="project in projectset.projects">
+                <li id="project_${project.id}">
+                  <a href="${project_url(offering, project)}"><h4>${project.short_name} - ${project.name}</h4></a>
+                  <p>${project.synopsis}</p>
+                </li>
+              </py:for>
+              <li>
+                <a>Add new project</a>
+                <div id="new_project_${projectset.id}">
+                  <p>TODO: Write the add project code</p>
+                </div>
+              </li>
+            </ul>
+          </li>
+        </py:for>
+        <li id="add_projectset">
+          <a>Add a new projectset</a>
+          <div id="new_projectset_div">
+            <form>
+            </form>
+          </div>
+        </li>
+      </ul>
+    </div>
+  </body>
+</html>

=== modified file 'ivle/webapp/base/rest.py'
--- ivle/webapp/base/rest.py	2009-02-23 00:41:57 +0000
+++ ivle/webapp/base/rest.py	2009-04-06 13:34:18 +0000
@@ -22,6 +22,7 @@
 import inspect
 
 import cjson
+import genshi.template
 
 from ivle.webapp.base.views import BaseView
 from ivle.webapp.errors import BadRequest, MethodNotAllowed, Unauthorized
@@ -141,10 +142,40 @@
             outjson = op(req, **opargs)
 
         req.content_type = self.content_type
+        self.write_json(req, outjson)
+
+    #This is a separate function to allow additional data to be passed through
+    def write_json(self, req, outjson):
         if outjson is not None:
             req.write(cjson.encode(outjson))
             req.write("\n")
 
+
+class XHTMLRESTView(JSONRESTView):
+    """A special type of RESTView which takes enhances the standard JSON
+    with genshi XHTML functions.
+    
+    XHTMLRESTViews should have a template, which is rendered using their
+    context. This is returned in the JSON as 'html'"""
+    template = None
+    ctx = genshi.template.Context()
+
+    def __init__(self, req, *args, **kwargs):
+        for key in kwargs:
+            setattr(self, key, kwargs[key])
+    
+    def render_fragment(self):
+        if self.template is None:
+            raise NotImplementedError()
+
+        return tmpl.generate(self.ctx).render('xhtml', doctype='xhtml')
+    
+    # This renders the template and adds it to the json
+    def write_json(self, req, outjson):
+        outjson["html"] = self.render_fragment()
+        req.write(cjson.encode(outjson))
+        req.write("\n")
+
 class named_operation(object):
     '''Declare a function to be accessible to HTTP users via the REST API.
     '''
@@ -165,4 +196,3 @@
     def __call__(self, func):
         func._rest_api_permission = self.permission
         return func
-

